@@ -25,15 +25,6 @@
 
 @implementation NGMimeMessageRfc822BodyGenerator
 
-+ (int)version {
-  return 2;
-}
-+ (void)initialize {
-  NSAssert2([super version] == 2,
-            @"invalid superclass (%@) version %i !",
-            NSStringFromClass([self superclass]), [super version]);
-}
-
 - (id<NGMimePartGenerator>)generatorForPart:(id<NGMimePart>)_part {
   id gen;
 
